# -*- coding: utf-8 -*-

import logging

try:
    from logging import NullHandler
except ImportError:
    class NullHandler(logging.Handler):
        def emit(self, record):
            pass

log = logging.getLogger(__name__)
logging.getLogger(__name__).addHandler(NullHandler())



from fwiffos.core import version
from fwiffos.cli.sudo import LetUs
from fwiffos.cli.admin import AdminCLI
from fwiffos.read.twitter import Twitter

class Calculator(object):

    def add(self, x, y):
      return x + y

    def multiply(self, x, y):
      return x * y

class FS(object):

    def __init__(self):
        self.filesystem = {'/': ['README']}

    def ls(self, cwd='/'):
        print(self.filesystem[cwd])

class Commands(object):
    def __init__(self):
        fs = FS()
        calc = Calculator()
        sudo = LetUs()
        twitter = Twitter()
        admin = AdminCLI()
        self._version = version
        self.__commands = {
            'ls': fs.ls,
            'add': calc.add,
            'mult': calc.multiply,
            'sudo': sudo.letus,
            'letus': sudo.letus,
            'read': twitter.tweet,
            'admin': admin.list,
        }

    def exec(self):
        return self.__commands

commands = Commands()



# -*- coding: utf-8 -*-

import ldap

ARCHIVEOS_DOMAIN='scupper.club'
ARCHIVEOS_BASEDN='dc=scupper,dc=club'

def list_admins():
    ldap_url = 'ldap://' + ARCHIVEOS_ROOT
    connect = ldap.initialize(ldap_url)
    connect.simple_bind_s()
    r = connect.search_s(ARCHIVEOS_BASEDN, ldap.SCOPE_SUBTREE, 'uid=*', displayName)
    return r



# -*- coding: utf-8 -*-

import os

"""Event Loop is managed here"""
"""From telehash v2
https://github.com/telehash/plinth/blob/master/plinth/core.py

import gevent
from gevent.server import DatagramServer

from .log import log
from .identity import SwitchID
from . import packet
from . import crypto
from .dht import DHT
from .exceptions import *
"""

class Node(object):
    pass



# -*- coding: utf-8 -*-

from setuptools import setup
from os import path


HERE = path.abspath(path.dirname(__file__))
with open(path.join(HERE, 'README.fwiffos.rst'), encoding='utf-8') as f:
    readme = f.read()

packages = [
    'fwiffos.core',
    'fwiffos.cli',
    'fwiffos.read',
    'fwiffos.write',
    'fwiffos.post',
    'fwiffos.scuttle',
]

requires = [
    'fire>=0.3.1',
    'ipython>=7.17.0',
    'python-ldap>=3.3.1',
]

setup(
    name='fwiffos',
    version='0.0.20',
    description='FwiffOS',
    long_description=readme,
    long_description_content_type='text/x-rst',
    author='SCUPPER™ Foundation',
    author_email='info@scupper.org',
    url='https://github.com/SCUPPERfoundation/fwiffo',
    license='MIT',
    packages=packages,
    package_data = {'': ['LICENSE', 'README.fwiffos.rst']},
    package_dir = {'fwiffos': 'fwiffos'},
    include_package_data=True,
    install_requires=requires,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    entry_points={"console_scripts":"fwiffish=fwiffos.cli.__main__:main"},
)

